@@ -1,15 +1,19 @@
 import requests
+import random
+from const import USER_AGENTS
+
 URL = 'https://finfo-api.vndirect.com.vn/v4/stock_prices?sort=date&q=code:%s~date:gte:%s~date:lte:%s&size=100000'
 def DICT_FILTER(x, y): return dict([(i, x[i]) for i in x if i in set(y)])
 
 
 KEYS = ['date', 'ceilingPrice', 'floorPrice', 'open',
-        'high', 'low', 'close', 'average', 'change', 'nmVolume']
+        'high', 'low', 'close', 'average', 'change']
 
 
 def getStockHistory(code, start_date, end_date):
     try:
-        r = requests.get(URL % (code, start_date, end_date))
+        r = requests.get(URL % (code, start_date, end_date),
+                         headers={"USER-AGENT": USER_AGENTS[random.randint(0, len(USER_AGENTS)-1)]})
         res = r.json()
     except Exception as e:
         return []
